<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="车牌号">
              <el-input v-model="querys[0].value" clearable placeholder="请输入车牌号" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="标识名称">
              <el-input v-model="querys[1].value" clearable placeholder="请输入标识名称" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
        <el-upload ref="upload" class="dib ml10" :auto-upload="true" :action="actionUrl"
          :on-progress="uploadProgressfile" :on-success="uploadSuccessfileSpace" :on-error="uploadExcelError"
          :multiple="false" :headers="header" :show-file-list="false" :before-upload="beforeUploadExcel"
          accept=".xls, .xlsx" style="margin:0px 10px;">
          <el-button icon="el-icon-upload2" type="success">
            <span>导入</span>
          </el-button>
        </el-upload>
        <el-button icon="el-icon-download" type="warning" @click="dowmTemplate">下载模板</el-button>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" />
        <el-table-column fixed type="index" width="55" label="序号" />
        <el-table-column fixed prop="code" label="车牌号" show-overflow-tooltip />
        <el-table-column prop="name" label="标识名称" show-overflow-tooltip />
        <el-table-column prop="vehicleType" label="车辆类型" show-overflow-tooltip />
        <el-table-column prop="brand" label="车辆品牌" show-overflow-tooltip />
        <el-table-column sortable prop="purchaseDate" label="购买时间" show-overflow-tooltip />
        <el-table-column prop="color" label="车辆颜色" show-overflow-tooltip />
        <el-table-column prop="fuelType" label="燃油类型" show-overflow-tooltip />
        <el-table-column prop="description" label="用途" show-overflow-tooltip />
        <!--        <el-table-column align="right" width="120px" label="操作">-->
        <!--          <template slot-scope="scope">-->
        <!--            <el-button size="mini" type="primary" plain @click="districtClick(scope.row)">车辆管区</el-button>-->
        <!--          </template>-->
        <!-- </el-table-column> -->
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <vechicle-manage-dialog ref="formModal" />
    <el-dialog title="车辆管区" :visible.sync="showDistrictDia" width="76%" :before-close="districtClose" top="8vh">
      <div>
        <CmgtDutyVehicleArea :licensePlate="licensePlate" />
      </div>
      <!-- <span slot="footer" class="dialog-footer">
        <el-button type="primary" :loading="loading" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>-->
    </el-dialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import VehicleManage from '@/api/manager/duty/vehicleManage.js'
import VechicleManageDialog from '@/views/Manage/duty/components/VechicleManageDialog'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import { mapState } from 'vuex'
import CmgtDutyVehicleArea from './CmgtDutyVehicleArea.vue'
export default {
  name: 'VehicleManage',
  components: {
    VechicleManageDialog,
    CmgtDutyVehicleArea
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/duty/vehicle/'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'code_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: [],
      licensePlate: '', // 选择车牌号
      showDistrictDia: false, // 控制测量管区弹层
    }
  },
  computed: mapState({
    header: state => {
      if (state.login && state.login.currentUser) {
        return {
          Authorization: `Bearer ${state.login.currentUser.token}`
        }
      }
      return {}
    },
    actionUrl: function () {
      return window.context.portal + '/manager/duty/vehicle/importExcel'
    }
  }),
  created() {
    // this.fuelTypes = dictContracts.getDictItemsFromCache('cmgt_rylx')
  },
  mounted() { },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      VehicleManage.loadVehicle(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    // 文件导入中钩子函数
    uploadProgressfile() {
      this.loading = true
    },
    // 导入后钩子函数
    uploadSuccessfileSpace(res, file) {
      if (res.state === true) {
        this.$notify({
          type: 'success',
          message: '导入数据成功',
          duration: 2200
          // offset: 80
        })
        this.loading = false
        this.loadData()
      } else {
        // 导入出错
        this.$notify({
          type: 'error',
          message: '导入数据失败',
          duration: 2200,
          offset: 80
        })
        this.loading = false
      }
    },
    uploadExcelError(err) {
      let data = JSON.parse(err.message)
      let msg = data.message ? data.message : '导入失败！'
      //提示
      this.$notify({
        type: 'error',
        message: this.$t(msg),
        duration: 2000
      })
      this.loading = false
    },
    // 文件导入前钩子函数
    beforeUploadExcel(file) {
      let filetype = file.name.substring(file.name.lastIndexOf('.') + 1)
      let typeCheck = filetype == 'xls' || 'xlsx'
      // const isLt = file.size / 1024 / 1024 < 10;
      if (!typeCheck) {
        this.$notify({
          showClose: true,
          message: '上传文档只能是xls或xlsx格式！',
          type: 'error',
          duration: 2200,
          offset: 80
        })
      }
      if (typeCheck) {
      }
      return typeCheck
    },
    // 下载模板按钮
    dowmTemplate() {
      window.open(
        window.context.portal + '/manager/duty/vehicle/downModel',
        '_blank'
      )
    },
    // 车辆管区按钮点击事件
    districtClick(row) {
      this.licensePlate = row.code
      this.showDistrictDia = true
    },
    // 车辆管区弹层关闭
    districtClose() {
      this.showDistrictDia = false
    },
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

.bbsl-btn-content {
  display: flex;
}

::v-deep .el-dialog__body {
  padding-top: 10px !important;
}
</style>
